from opsorchestrator.core.data_model.technology import Technology
from opsorchestrator.core.data_model.component import Component

class Datalake(Technology):
    pass

class ThreatFeed(Component):
    pass