"""Contracts for Zscaler Technology"""
from opsorchestrator.core.data_model.technology import Technology
from opsorchestrator.core.data_model.component import Component

class Zscaler(Technology):
    pass
class ZIA(Component):
    pass
class ZPA(Component):
    pass
class ZCC(Component):
    pass
