"""Contracts for ServiceNow Technology"""
from opsorchestrator.core.data_model.technology import Technology
from opsorchestrator.core.data_model.component import Component

class ServiceNow(Technology):
    pass

class Incident(Component):
    pass
